@@ -5,12 +5,15 @@ sentry.plugins.bases.issue
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from sentry.conf import settings
 from sentry.models import GroupMeta
 from sentry.plugins import Plugin
 from django import forms
 from django.core.urlresolvers import reverse
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
+from social_auth.models import UserSocialAuth
+from sentry.utils.auth import get_auth_providers
 
 
 class NewIssueForm(forms.Form):
@@ -24,6 +27,8 @@ class IssuePlugin(Plugin):
 
     create_issue_template = 'sentry/plugins/bases/issue/create_issue.html'
     not_configured_template = 'sentry/plugins/bases/issue/not_configured.html'
+    needs_auth_template = 'sentry/plugins/bases/issue/needs_auth.html'
+    auth_provider = None
 
     def __init__(self, *args, **kwargs):
         super(IssuePlugin, self).__init__(*args, **kwargs)
@@ -55,13 +60,52 @@ class IssuePlugin(Plugin):
     def is_configured(self, request, project, **kwargs):
         raise NotImplementedError
 
+    def get_auth_for_user(self, user, **kwargs):
+        """
+        Return a ``UserSocialAuth`` object for the given user based on this plugins ``auth_provider``.
+        """
+        assert self.auth_provider, 'There is no auth provider configured for this plugin.'
+
+        if not user.is_authenticated():
+            return None
+
+        try:
+            return UserSocialAuth.objects.filter(user=user, provider=self.auth_provider)[0]
+        except IndexError:
+            return None
+
+    def needs_auth(self, request, project, **kwargs):
+        """
+        Return ``True`` if the authenticated user needs to associate an auth service before
+        performing actions with this plugin.
+        """
+        if self.auth_provider is None:
+            return False
+
+        if not request.user.is_authenticated():
+            return True
+
+        return bool(not UserSocialAuth.objects.filter(user=request.user, provider=self.auth_provider).exists())
+
     def get_new_issue_title(self, **kwargs):
+        """
+        Return a string for the "Create new issue" action label.
+        """
         return 'Create %s Issue' % self.get_title()
 
     def get_issue_url(self, group, issue_id, **kwargs):
+        """
+        Given an issue_id (string) return an absolute URL to the issue's details
+        page.
+        """
         raise NotImplementedError
 
     def get_issue_label(self, group, issue_id, **kwargs):
+        """
+        Given an issue_id (string) return a string representing the issue.
+
+        e.g. GitHub represents issues as GH-XXX
+        """
         return '#%s' % issue_id
 
     def create_issue(self, request, group, form_data, **kwargs):
@@ -76,9 +120,35 @@ class IssuePlugin(Plugin):
             'title': self._get_group_title(request, group, event),
         }
 
+    def has_auth_configured(self, **kwargs):
+        if not self.auth_provider:
+            return True
+
+        return self.auth_provider in get_auth_providers()
+
     def view(self, request, group, **kwargs):
-        if not self.is_configured(project=group.project, request=request):
-            return self.render(self.not_configured_template)
+        has_auth_configured = self.has_auth_configured()
+        if not (has_auth_configured and self.is_configured(project=group.project, request=request)):
+            if self.auth_provider:
+                required_auth_settings = settings.AUTH_PROVIDERS[self.auth_provider]
+            else:
+                required_auth_settings = None
+
+            return self.render(self.not_configured_template, {
+                'title': self.get_title(),
+                'project': group.project,
+                'has_auth_configured': has_auth_configured,
+                'required_auth_settings': required_auth_settings,
+            })
+
+        if self.needs_auth(project=group.project, request=request):
+            return self.render(self.needs_auth_template, {
+                'title': self.get_title(),
+                'project': group.project,
+            })
+
+        if GroupMeta.objects.get_value(group, '%s:tid' % self.get_conf_key(), None):
+            return None
 
         prefix = self.get_conf_key()
         event = group.get_latest_event()
